.. dlk documentation master file, created by
   sphinx-quickstart on Thu Dec 23 21:05:09 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Deep Learning ToolKit
=====================

.. toctree::
   :maxdepth: 1
   :name: Introduction
   :caption: Introduction

   introduction

.. toctree::
   :name: api
   :caption: API References
   :maxdepth: 3

   dlk.core
   dlk.data
   dlk.managers
   dlk.utils


.. toctree::
   :maxdepth: 1
   :name: Appointments
   :caption: Appointments

   appointment

.. toctree::
   :maxdepth: 1
   :name: processor
   :caption: Process Progress

   process_progress

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
